pub enum AggregateModifyKind {
ReadOnly,
Shareable,
ReadWrite,
}Expand description
Modifier kind for FINALFUNC_MODIFY / MFINALFUNC_MODIFY in CREATE AGGREGATE.
See https://www.postgresql.org/docs/current/sql-createaggregate.html
Variants
ReadOnly
The final function does not modify the transition state.
The transition state may be shared between aggregate calls.
ReadWrite
The final function may modify the transition state.