pub struct SecurityLabel {
pub provider: Option<Ident>,
pub object_kind: SecurityLabelObjectKind,
pub object_name: ObjectName,
pub label: Option<Value>,
}Expand description
A SECURITY LABEL statement.
Note: this is a PostgreSQL-specific statement. https://www.postgresql.org/docs/current/sql-securitylabel.html
Fields
provider: Option<Ident>Optional FOR provider_name clause.
object_kind: SecurityLabelObjectKindThe kind of object the label is applied to.
object_name: ObjectNameThe name of the object the label is applied to.
label: Option<Value>The label string, or None for IS NULL.