Struct sqlparser::dialect::GenericDialect
source · [−]pub struct GenericDialect;Trait Implementations
sourceimpl Debug for GenericDialect
impl Debug for GenericDialect
sourceimpl Default for GenericDialect
impl Default for GenericDialect
sourcefn default() -> GenericDialect
fn default() -> GenericDialect
Returns the “default value” for a type. Read more
sourceimpl Dialect for GenericDialect
impl Dialect for GenericDialect
sourcefn is_identifier_start(&self, ch: char) -> bool
fn is_identifier_start(&self, ch: char) -> bool
Determine if a character is a valid start character for an unquoted identifier
sourcefn is_identifier_part(&self, ch: char) -> bool
fn is_identifier_part(&self, ch: char) -> bool
Determine if a character is a valid unquoted identifier character
sourcefn is_delimited_identifier_start(&self, ch: char) -> bool
fn is_delimited_identifier_start(&self, ch: char) -> bool
Determine if a character starts a quoted identifier. The default
implementation, accepting “double quoted” ids is both ANSI-compliant
and appropriate for most dialects (with the notable exception of
MySQL, MS SQL, and sqlite). You can accept one of characters listed
in Word::matching_end_quote here Read more