pub enum UserDefinedTypeRangeOption {
Subtype(DataType),
SubtypeOpClass(ObjectName),
Collation(ObjectName),
Canonical(ObjectName),
SubtypeDiff(ObjectName),
MultirangeTypeName(ObjectName),
}Expand description
Options for PostgreSQL CREATE TYPE ... AS RANGE statement.
Range types are data types representing a range of values of some element type (called the range’s subtype). These options configure the behavior of the range type.
PostgreSQL Documentation
See: https://www.postgresql.org/docs/current/sql-createtype.html
Examples
CREATE TYPE int4range AS RANGE (
SUBTYPE = int4,
SUBTYPE_OPCLASS = int4_ops,
CANONICAL = int4range_canonical,
SUBTYPE_DIFF = int4range_subdiff
);Variants
Subtype(DataType)
The element type that the range type will represent: SUBTYPE = subtype
SubtypeOpClass(ObjectName)
The operator class for the subtype: SUBTYPE_OPCLASS = subtype_operator_class
Collation(ObjectName)
Collation to use for ordering the subtype: COLLATION = collation
Canonical(ObjectName)
Function to convert range values to canonical form: CANONICAL = canonical_function
SubtypeDiff(ObjectName)
Function to compute the difference between two subtype values: SUBTYPE_DIFF = subtype_diff_function
MultirangeTypeName(ObjectName)
Name of the corresponding multirange type: MULTIRANGE_TYPE_NAME = multirange_type_name