pub struct LambdaFunctionParameter {
pub name: Ident,
pub data_type: Option<DataType>,
}Expand description
A parameter to a lambda function, optionally with a data type.
Fields
name: IdentThe name of the parameter
data_type: Option<DataType>The optional data type of the parameter Snowflake Syntax